import { Image, View } from "@tarojs/components"
import Taro from "@tarojs/taro"
import { goLink } from "@/common/common"
import styles  from './index.module.scss'
import { formatHashTag, formatImgUrl } from "@/common/fotmat"
import LabAndImg from "@/components/LabAndImg"
import MCheckbox from "@/components/checkbox";
import { useCallback, useEffect, useRef, useState } from "react"

type Params = {
    productList?: any[],
    onSelectIds?: (val: number[]) => void
    selectStatus?: false|true
}
export default ({productList = [], onSelectIds, selectStatus = false}:Params) => {
    const [list, setList] = useState<any[]>([])
    useEffect(() => {
        setList(() => [...productList])
    },[productList]) 

    useEffect(() => {
        if(list.length) {
            list.map(item => {
                item.check = selectStatus
            })
        }
        setList(() => [...list])
    }, [selectStatus])

    const onChangeSelect = (item) => {
        if(item.check) {
            onClose(item)
        } else {
            onSelect(item)
        }
    }

    //选中和取消选中
    const onSelect = (item) => {
        item.check = true
        setList(() => ([...list]))
    }
    const onClose = (item) => {
        item.check = false
        setList(() => ([...list]))
    }

    //监听数据变化
    useEffect(() => {
        let ids: number[] = []
        list.map(item => {
            if(item.check) ids.push(item.id)
        })
        onSelectIds?.(ids)
    }, [list])

    return (
        <View className={styles.products_list}>
            {list?.map(item => {
                return <View className={styles.products_item} onClick={() => onChangeSelect(item)}>
                    <View className={styles.checkbox}  onClick={(e) => e.stopPropagation()}>
                        <MCheckbox status={item.check} onSelect={() => onSelect(item)} onClose={() => onClose(item)}/>
                    </View>
                    <View className={styles.item_img}>
                        <LabAndImg value={{lab:item.lab,rgb:item.rgb,texture_url:item.texture_url}}/>
                        <View className={styles.num}>{item.product_color_count}色</View>
                    </View>
                    <View className={styles.item_con}>
                        <View className={styles.title}><text>{formatHashTag(item.product_code, '')} </text>{item.product_name}</View>
                        <View className={styles.tag_list}>
                            <View className={styles.tag}>{item.width}</View>
                            <View className={styles.tag_g}>{item.weight_density}</View>
                        </View>
                        <View className={styles.introduce}>{item.component}</View>
                    </View>
                </View>
            })}
            <View className="common_safe_area_y"></View>
        </View>
    )
}
